package com.ruoyi.project.patrol.dev.service;

import java.util.List;
import com.ruoyi.project.patrol.dev.domain.TDevDoor;

/**
 * 常闭式防爆门/防火门Service接口
 * 
 * @author admin
 * @date 2023-11-07
 */
public interface ITDevDoorService 
{
    /**
     * 查询常闭式防爆门/防火门
     * 
     * @param id 常闭式防爆门/防火门主键
     * @return 常闭式防爆门/防火门
     */
    public TDevDoor selectTDevDoorById(Long id);

    /**
     * 查询常闭式防爆门/防火门列表
     * 
     * @param tDevDoor 常闭式防爆门/防火门
     * @return 常闭式防爆门/防火门集合
     */
    public List<TDevDoor> selectTDevDoorList(TDevDoor tDevDoor);

    /**
     * 新增常闭式防爆门/防火门
     * 
     * @param tDevDoor 常闭式防爆门/防火门
     * @return 结果
     */
    public int insertTDevDoor(TDevDoor tDevDoor);

    /**
     * 修改常闭式防爆门/防火门
     * 
     * @param tDevDoor 常闭式防爆门/防火门
     * @return 结果
     */
    public int updateTDevDoor(TDevDoor tDevDoor);

    /**
     * 批量删除常闭式防爆门/防火门
     * 
     * @param ids 需要删除的常闭式防爆门/防火门主键集合
     * @return 结果
     */
    public int deleteTDevDoorByIds(Long[] ids);

    /**
     * 删除常闭式防爆门/防火门信息
     * 
     * @param id 常闭式防爆门/防火门主键
     * @return 结果
     */
    public int deleteTDevDoorById(Long id);
}
